Build a facet statistics report (preferred alias)
Source:R/api-reports.R
facet_statistics_report.RdBuild a facet statistics report (preferred alias)
Arguments
- fit
Output from
fit_mfrm().- diagnostics
Optional output from
diagnose_mfrm().- metrics
Numeric columns in
diagnostics$measuresto summarize.- ruler_width
Width of the fixed-width ruler used for
M/S/Q/Xmarks.- distribution_basis
Which distribution basis to keep in the appended precision summary:
"both"(default),"sample", or"population".- se_mode
Which standard-error mode to keep in the appended precision summary:
"both"(default),"model", or"fit_adjusted".
Details
summary(out) is supported through summary().
plot(out) is dispatched through plot() for class
mfrm_facet_statistics (type = "means", "sds", "ranges").
Interpreting output
facet-level means/SD/ranges of selected metrics (
Estimate, fit indices,SE).fixed-width ruler rows (
M/S/Q/X) for compact profile scanning.
Typical workflow
Run
facet_statistics_report(fit).Inspect summary/ranges for anomalous facets.
Cross-check flagged facets with fit and chi-square diagnostics. The returned bundle now includes:
precision_summary: facet precision/separation indices byDistributionBasisandSEModevariability_tests: fixed/random variability tests by facetse_modes: compact list of available SE modes by facet
Examples
toy <- load_mfrmr_data("example_core")
fit <- fit_mfrm(toy, "Person", c("Rater", "Criterion"), "Score", method = "JML", maxit = 25)
out <- facet_statistics_report(fit)
summary(out)
#> mfrmr Facet Profile Summary
#> Class: mfrm_facet_statistics
#> Components (6): table, ranges, settings, precision_summary, variability_tests, se_modes
#>
#> Facet-profile overview
#> Facets Rows Metrics PrecisionRows VariabilityRows
#> 3 12 4 12 3
#>
#> Facet-profile rows: precision_summary
#> Facet Levels DistributionBasis SEMode SEColumn ObservedMean
#> Criterion 4 population fit_adjusted RealSE 0.000
#> Criterion 4 population model ModelSE 0.000
#> Criterion 4 sample fit_adjusted RealSE 0.000
#> Criterion 4 sample model ModelSE 0.000
#> Person 48 population fit_adjusted RealSE 0.001
#> Person 48 population model ModelSE 0.001
#> Person 48 sample fit_adjusted RealSE 0.001
#> Person 48 sample model ModelSE 0.001
#> Rater 4 population fit_adjusted RealSE 0.000
#> Rater 4 population model ModelSE 0.000
#> ObservedSD RMSE TrueSD ObservedVariance ErrorVariance TrueVariance Separation
#> 0.249 0.099 0.228 0.062 0.010 0.052 2.310
#> 0.249 0.097 0.229 0.062 0.010 0.052 2.347
#> 0.287 0.099 0.270 0.082 0.010 0.073 2.729
#> 0.287 0.097 0.270 0.082 0.010 0.073 2.771
#> 1.089 0.365 1.026 1.186 0.133 1.053 2.811
#> 1.089 0.347 1.033 1.186 0.120 1.066 2.977
#> 1.101 0.365 1.038 1.212 0.133 1.078 2.845
#> 1.101 0.347 1.045 1.212 0.120 1.091 3.012
#> 0.271 0.099 0.253 0.074 0.010 0.064 2.563
#> 0.271 0.097 0.253 0.074 0.010 0.064 2.595
#> Strata Reliability SEAvailable MeanSE MedianSE MeanInfit MeanOutfit FixedChiSq
#> 3.413 0.842 4 0.099 0.098 0.994 1.019 25.804
#> 3.462 0.846 4 0.097 0.097 0.994 1.019 25.804
#> 3.972 0.882 4 0.099 0.098 0.994 1.019 25.804
#> 4.028 0.885 4 0.097 0.097 0.994 1.019 25.804
#> 4.082 0.888 48 0.360 0.350 1.000 1.019 384.563
#> 4.303 0.899 48 0.344 0.330 1.000 1.019 384.563
#> 4.126 0.890 48 0.360 0.350 1.000 1.019 384.563
#> 4.350 0.901 48 0.344 0.330 1.000 1.019 384.563
#> 3.751 0.868 4 0.099 0.099 0.994 1.019 30.881
#> 3.794 0.871 4 0.097 0.097 0.994 1.019 30.881
#> FixedDF FixedProb RandomVar RandomChiSq RandomDF RandomProb
#> 3 0 0.073 2.997 2 0.223
#> 3 0 0.073 2.997 2 0.223
#> 3 0 0.073 2.997 2 0.223
#> 3 0 0.073 2.997 2 0.223
#> 47 0 1.091 45.462 46 0.495
#> 47 0 1.091 45.462 46 0.495
#> 47 0 1.091 45.462 46 0.495
#> 47 0 1.091 45.462 46 0.495
#> 3 0 0.089 2.999 2 0.223
#> 3 0 0.089 2.999 2 0.223
#>
#> Settings
#> Setting Value
#> metrics Estimate, Infit, Outfit, SE
#> ruler_width 41
#> marker_legend mean, +/-1 SD, +/-2 SD, +/-3 SD
#> distribution_basis both
#> se_mode both
#>
#> Notes
#> - Facet profile summary including distribution basis, SE mode, and variability tests.
p_fs <- plot(out, draw = FALSE)
class(p_fs)
#> [1] "mfrm_plot_data" "list"